flake8-import-style
===================

A flake8 plugin to ensure explicit module imports.

For more information, see `github.com/sfstpala/flake8-import-style <https://github.com/sfstpala/flake8-import-style/>`_.
